@@ -59,7 +59,7 @@ class Dataset():
         return self.client._poll(self, {'PENDING', 'IMPORTING'}, timeout=timeout)
 
     def wait_for_inspection(self, timeout=900):
-        return self.client._poll(self, {'PENDING', 'IMPORTING', 'INSPECTING'}, timeout=timeout)
+        return self.client._poll(self, {'PENDING', 'UPLOADING', 'IMPORTING', 'INSPECTING'}, timeout=timeout)
 
     def get_status(self):
         return self.describe().latest_dataset_version.status
