@@ -43,14 +43,20 @@ class Deployment():
     def start(self):
         return self.client.start_deployment(self.deployment_id)
 
+    def set_model_version(self, model_version):
+        return self.client.set_deployment_model_version(self.deployment_id, model_version)
+
     def stop(self):
         return self.client.stop_deployment(self.deployment_id)
 
     def delete(self):
         return self.client.delete_deployment(self.deployment_id)
 
-    def batch_predict(self, input_location=None, output_location=None, name=None, refresh_schedule=None):
-        return self.client.batch_predict(self.deployment_id, input_location, output_location, name, refresh_schedule)
+    def batch_predict(self, input_location=None, output_location=None, name=None, refresh_schedule=None, global_prediction_args=None):
+        return self.client.batch_predict(self.deployment_id, input_location, output_location, name, refresh_schedule, global_prediction_args)
+
+    def batch_prediction_from_upload(self, name=None, global_prediction_args=None):
+        return self.client.batch_prediction_from_upload(self.deployment_id, name, global_prediction_args)
 
     def list_batch_predictions(self):
         return self.client.list_batch_predictions(self.deployment_id)
